@@ -1,5 +1,5 @@
 openloop = {
-    "name": "openloop.json",
+    "name": "open.json",
     "importCode": "",
     "blocks": {
         "1": {
@@ -61,27 +61,20 @@ openloop = {
             ],
             "code": [
                 {
-                    "id": 1,
+                    "name": "Input",
                     "type": "input",
+                    "subtype": "output",
                     "legend": "input",
-                    "color": "",
+                    "color": "red",
                     "check": True
                 },
                 {
-                    "id": 2,
+                    "name": "Sys (TF)",
                     "type": "system",
                     "subtype": "output",
                     "legend": "output",
-                    "color": "",
+                    "color": "cyan",
                     "check": True
-                },
-                {
-                    "id": 2,
-                    "type": "system",
-                    "subtype": "input",
-                    "legend": "",
-                    "color": "",
-                    "check": False
                 }
             ],
             "coords": [
